@@ -152,7 +152,9 @@ impl<K, F: Fn(Option<&K>) -> bool> Condition<K> for F {
 /// Common conditions to wait for
 pub mod conditions {
     pub use super::Condition;
-    use k8s_openapi::apiextensions_apiserver::pkg::apis::apiextensions::v1::CustomResourceDefinition;
+    use k8s_openapi::{
+        api::core::v1::Pod, apiextensions_apiserver::pkg::apis::apiextensions::v1::CustomResourceDefinition,
+    };
     use kube_client::Resource;
 
     /// An await condition that returns `true` once the object has been deleted.
@@ -189,6 +191,21 @@ pub mod conditions {
         }
     }
 
+    /// An await condition for `Pod` that returns `true` once it is running
+    #[must_use]
+    pub fn is_pod_running() -> impl Condition<Pod> {
+        |obj: Option<&Pod>| {
+            if let Some(pod) = &obj {
+                if let Some(status) = &pod.status {
+                    if let Some(phase) = &status.phase {
+                        return phase == "Running";
+                    }
+                }
+            }
+            false
+        }
+    }
+
     /// See [`Condition::not`]
     #[derive(Copy, Clone, Debug, PartialEq, Eq)]
     pub struct Not<A>(pub(super) A);
@@ -247,7 +264,7 @@ pub mod delete {
     ///
     /// # Errors
     ///
-    /// Returns an [`Error`] if the object was unable to be deleted, or if the wait was interrupted.
+    /// Returns an [`Error`](enum@super::Error) if the object was unable to be deleted, or if the wait was interrupted.
     #[allow(clippy::module_name_repetitions)]
     pub async fn delete_and_finalize<K: Clone + Debug + Send + DeserializeOwned + Resource + 'static>(
         api: Api<K>,
